@@ -1,6 +1,4 @@
-#  Copyright (C) 2016 - Yevgen Muntyan
-#  Copyright (C) 2016 - Ignacio Casal Quinteiro
-#  Copyright (C) 2016 - Arnavion
+#  Copyright (C) 2016 The Gvsbuild Authors
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -14,6 +12,7 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program; if not, see <http://www.gnu.org/licenses/>.
+
 import json
 import sys
 from typing import List
@@ -51,9 +50,10 @@ def set_projects_latest_versions(projects):
                     str(project.latest_version)
                 ) > version.parse(project.version)
 
-    except lastversion.utils.ApiCredentialsError:
+    except lastversion.exceptions.ApiCredentialsError:
         print(
-            "Create or update the GITHUB token at https://github.com/settings/tokens, then set or update the token environmental variable with:\n$env:GITHUB_API_TOKEN=xxxxxxxxxxxxxxx"
+            "Create or update the GITHUB token at https://github.com/settings/tokens, then set or update the token "
+            "environmental variable with:\n$env:GITHUB_API_TOKEN=xxxxxxxxxxxxxxx"
         )
         exit(1)
 
