@@ -1,6 +1,4 @@
-#  Copyright (C) 2016 - Yevgen Muntyan
-#  Copyright (C) 2016 - Ignacio Casal Quinteiro
-#  Copyright (C) 2016 - Arnavion
+#  Copyright (C) 2016 The Gvsbuild Authors
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -16,22 +14,21 @@
 #  along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 from gvsbuild.utils.base_builders import Meson
-from gvsbuild.utils.base_expanders import GitRepo
+from gvsbuild.utils.base_expanders import Tarball
 from gvsbuild.utils.base_project import Project, project_add
 
 
 @project_add
-class Libffi(GitRepo, Meson):
+class Libffi(Tarball, Meson):
     def __init__(self):
         Project.__init__(
             self,
             "libffi",
-            repo_url="https://github.com/wingtk/libffi.git",
-            fetch_submodules=False,
-            tag="27470bd6b428fe598b39f19610200fb0e975ce5d",
+            version="3.4.6",
+            archive_url="https://github.com/libffi/libffi/releases/download/v{version}/libffi-{version}.tar.gz",
             dependencies=["ninja", "meson"],
         )
 
     def build(self):
-        Meson.build(self)
+        Meson.build(self, meson_params="-Dtests=false")
         self.install(r"LICENSE share\doc\libffi")
