@@ -1,6 +1,4 @@
-#  Copyright (C) 2016 - Yevgen Muntyan
-#  Copyright (C) 2016 - Ignacio Casal Quinteiro
-#  Copyright (C) 2016 - Arnavion
+#  Copyright (C) 2016 The Gvsbuild Authors
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -22,52 +20,72 @@ from gvsbuild.utils.base_project import Project, project_add
 
 
 @project_add
-class OpenSSL(Tarball, Project):
+class OpenSSLBase(Tarball, Project):
     def __init__(self):
         Project.__init__(
             self,
-            "openssl",
-            version="3.1.0",
+            "openssl-base",
+            version="3.2.1",
             archive_url="https://www.openssl.org/source/openssl-{version}.tar.gz",
-            hash="aaa925ad9828745c4cad9d9efeb273deca820f2cdcf2c3ac7d7c1212b7c497b4",
+            hash="83c7329fe52c850677d75e5d0b0ca245309b97e8ecbcfdc1dfdc4ab9fac35b39",
             dependencies=[
                 "perl",
                 "nasm",
                 "msys2",
             ],
+            patches=["0001-crypto-providers-config.patch"],
         )
 
     def build(self):
-        common_options = r"no-ssl2 no-ssl3 no-comp --openssldir=%(gtk_dir)s/etc/ssl --prefix=%(gtk_dir)s"
-
+        common_options = r"enable-fips no-comp no-docs no-ssl3 --openssldir=%(gtk_dir)s/etc/ssl --prefix=%(gtk_dir)s"
         debug_option = "debug-" if self.builder.opts.configuration == "debug" else ""
-        # Note that we want to give priority to the system perl version.
-        # Using the msys2 one might endup giving us a broken build
-        #        add_path = ';'.join([os.path.join(self.builder.perl_dir, 'bin'),
-        #                             os.path.join(self.builder.opts.msys_dir, 'usr', 'bin')])
-        add_path = None
+        target_option = "VC-WIN32 " if self.builder.x86 else "VC-WIN64A "
 
-        if self.builder.x86:
-            self.exec_vs(
-                r"%(perl_dir)s\bin\perl.exe Configure "
-                + debug_option
-                + "VC-WIN32 "
-                + common_options
-            )
-        else:
-            self.exec_vs(
-                r"%(perl_dir)s\bin\perl.exe Configure "
-                + debug_option
-                + "VC-WIN64A "
-                + common_options
-            )
+        self.exec_vs(
+            r"%(perl_dir)s\bin\perl.exe Configure "
+            + debug_option
+            + target_option
+            + common_options
+        )
 
         with contextlib.suppress(Exception):
-            self.exec_vs(r"nmake /nologo clean", add_path=add_path)
-        self.exec_vs(r"nmake /nologo", add_path=add_path)
+            self.exec_vs(r"nmake /nologo clean")
+        self.exec_vs(r"nmake /nologo")
         self.exec_vs(r"%(perl_dir)s\bin\perl.exe mk-ca-bundle.pl -n cert.pem")
-        self.exec_vs(r"nmake /nologo install", add_path=add_path)
+        self.exec_vs(r"nmake /nologo install")
 
         self.install(r".\cert.pem bin")
         self.install(r".\LICENSE share\doc\openssl")
         self.install_pc_files()
+
+
+@project_add
+class OpenSSL(Tarball, Project):
+    def __init__(self):
+        Project.__init__(
+            self,
+            "openssl",
+            version="3.0.8",
+            archive_url="https://www.openssl.org/source/old/{major}.{minor}/openssl-{version}.tar.gz",
+            hash="6c13d2bf38fdf31eac3ce2a347073673f5d63263398f1f69d0df4a41253e4b3e",
+            dependencies=[
+                "openssl-base",
+            ],
+        )
+
+    def build(self):
+        common_options = "enable-fips no-ssl3 no-comp --openssldir=%(gtk_dir)s/etc/ssl --prefix=%(gtk_dir)s"
+        debug_option = "debug-" if self.builder.opts.configuration == "debug" else ""
+        target_option = "VC-WIN32 " if self.builder.x86 else "VC-WIN64A "
+
+        self.exec_vs(
+            r"%(perl_dir)s\bin\perl.exe Configure "
+            + debug_option
+            + target_option
+            + common_options
+        )
+
+        with contextlib.suppress(Exception):
+            self.exec_vs(r"nmake /nologo clean")
+        self.exec_vs(r"nmake /nologo")
+        self.exec_vs(r"nmake /nologo install_fips")
