@@ -1,6 +1,4 @@
-#  Copyright (C) 2016 - Yevgen Muntyan
-#  Copyright (C) 2016 - Ignacio Casal Quinteiro
-#  Copyright (C) 2016 - Arnavion
+#  Copyright (C) 2016 The Gvsbuild Authors
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -189,7 +187,7 @@ def dirlist2set(st_dir, add_dirs=False, skipped_dir=None):
 def make_zip_hash(files):
     """Calculate an hash of all the files to put in a zip file."""
     hash_calc = hashlib.sha256()
-    for file_name in sorted(list(files)):
+    for file_name in sorted(files):
         # add also the file full path, to support only moving files in the zip
         hash_calc.update(file_name.lower().encode("utf-8"))
         if os.path.isfile(file_name):
@@ -210,7 +208,7 @@ def make_zip(name, files, skip_spc=0):
     """
     log.start_verbose(f"Creating zip file {name} with {len(files)} files")
     with zipfile.ZipFile(f"{name}.zip", "w", compression=zipfile.ZIP_DEFLATED) as zf:
-        for f in sorted(list(files)):
+        for f in sorted(files):
             zf.write(f, arcname=f[skip_spc:])
     log.end()
 
