@@ -1,6 +1,4 @@
-#  Copyright (C) 2016 - Yevgen Muntyan
-#  Copyright (C) 2016 - Ignacio Casal Quinteiro
-#  Copyright (C) 2016 - Arnavion
+#  Copyright (C) 2016 The Gvsbuild Authors
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -17,7 +15,6 @@
 
 """Base project class, used also for tools."""
 
-
 import datetime
 import os
 import pathlib
@@ -96,7 +93,7 @@ class Project(Generic[P]):
         self.dependencies = []
         self.patches = []
         self.archive_url = None
-        self.archive_file_name = None
+        self.archive_filename = None
         self.tarbomb = False
         self.type = None
         self.version = None
@@ -110,7 +107,7 @@ class Project(Generic[P]):
         self.extra_env = {}
         self.tag = None
         self.repo_url = None
-        self.archive_file_name = None
+        self.archive_filename = None
 
         for k in kwargs:
             setattr(self, k, kwargs[k])
@@ -133,8 +130,8 @@ class Project(Generic[P]):
 
         if self.archive_url:
             self.archive_url = self.archive_url.format(**version_params)
-        if self.archive_file_name:
-            self.archive_file_name = self.archive_file_name.format(**version_params)
+        if self.archive_filename:
+            self.archive_filename = self.archive_filename.format(**version_params)
 
         # register version params for use from derived classes
         self.version_params = version_params
@@ -417,12 +414,12 @@ class Project(Generic[P]):
 
         src_dir = os.path.join(self._get_working_dir(), base_dir)
         log.debug(f"Copy .pc files from {src_dir}")
-        bin_dir = os.path.join(self.builder.gtk_dir, "bin").replace("\\", "/")
+        gtk_dir = self.builder.gtk_dir.replace("\\", "/")
         for f in os.scandir(src_dir):
             if f.is_file():
                 log.debug(f" {f.name}")
                 content = pathlib.Path(f.path).read_text()
-                _t = content.replace("@prefix@", bin_dir)
+                _t = content.replace("@prefix@", gtk_dir)
                 content = _t
                 _t = content.replace("@version@", self.version)
                 content = _t
