@@ -1,6 +1,4 @@
-#  Copyright (C) 2016 - Yevgen Muntyan
-#  Copyright (C) 2016 - Ignacio Casal Quinteiro
-#  Copyright (C) 2016 - Arnavion
+#  Copyright (C) 2016 The Gvsbuild Authors
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -80,6 +78,10 @@ class Builder:
                     f"Removing git expand dir ({self.opts.git_expand_dir})"
                 ):
                     rmtree_full(self.opts.git_expand_dir, retry=True)
+                with log.simple_oper(
+                    f"Removing archives download dir ({opts.archives_download_dir})"
+                ):
+                    rmtree_full(opts.archives_download_dir)
                 if not opts.keep_tools:
                     with log.simple_oper(f"Removing tools dir ({opts.tools_root_dir})"):
                         rmtree_full(opts.tools_root_dir, retry=True)
@@ -131,7 +133,7 @@ class Builder:
         if python:
             rt.append(
                 '/p:PythonPath="%(python_dir)s" /p:PythonDir="%(python_dir)s"'
-                % dict(python_dir=python)
+                % {"python_dir": python}
             )
 
         if log.verbose_on():
@@ -446,8 +448,8 @@ class Builder:
     def preprocess(self):
         for proj in Project.list_projects():
             if proj.archive_url:
-                if proj.archive_file_name:
-                    archive = proj.archive_file_name
+                if proj.archive_filename:
+                    archive = proj.archive_filename
                 else:
                     url = proj.archive_url
                     archive = url[url.rfind("/") + 1 :]
@@ -907,14 +909,14 @@ class Builder:
     def __sub_vars(self, s):
         if "%" not in s:
             return s
-        d = dict(
-            platform=self.opts.platform,
-            configuration=self.opts.configuration,
-            build_dir=self.opts.build_dir,
-            vs_ver=self.opts.vs_ver,
-            gtk_dir=self.gtk_dir,
-            vs_ver_year=self.vs_ver_year,
-        )
+        d = {
+            "platform": self.opts.platform,
+            "configuration": self.opts.configuration,
+            "build_dir": self.opts.build_dir,
+            "vs_ver": self.opts.vs_ver,
+            "gtk_dir": self.gtk_dir,
+            "vs_ver_year": self.vs_ver_year,
+        }
         python = None
         if self.__project is not None:
             d["pkg_dir"] = self.__project.pkg_dir
@@ -939,7 +941,9 @@ class Builder:
             env=self.vs_env,
         )
 
-    def exec_cargo(self, params="", working_dir=None, rustc_opts=None):
+    def exec_cargo(
+        self, params="", working_dir=None, rustc_opts=None, rust_version="stable"
+    ):
         cmd = "cargo"
         if self.opts.cargo_opts:
             cmd += f" {self.opts.cargo_opts}"
@@ -957,7 +961,7 @@ class Builder:
         # set platform
         rustup = os.path.join(cargo_home, "rustup.exe")
         self.__execute(
-            f'{rustup} default stable-{"i686" if self.x86 else "x86_64"}-pc-windows-msvc',
+            f'{rustup} default {rust_version}-{"i686" if self.x86 else "x86_64"}-pc-windows-msvc',
             env=env,
         )
 
